% zeropad: zero-pad an array to given shape.
%
% Arguments:
%   x     - The array to pad with zeros.  The contents of will be
%           approximately centered in the result.
%   shape - The shape of the result.
%
% Examples:
%   zeropad(x, size(y));
%   zeropad(x, 512);
%   zeropad(x, [200, 300]);

function z = zeropad(x, shape)
    xshape = size(x);
    rank = length(xshape);
    if length(shape) ~= rank
        printf('ERROR - bad number of dimensions\n');
    end
    diff = shape - xshape;
    if min(diff) < 0
        printf(['ERROR - output dimensions must be larger or equal input ' ...
                'dimensions\n']);
    end
    offset = floor(diff/2);
    first = offset + 1;
    last = offset + xshape;
    z = zeros(shape);
    if rank == 1
        i1 = first(1); j1 = last(1);
        z(i1:j1) = x;
    elseif rank == 2
        i1 = first(1); j1 = last(1);
        i2 = first(2); j2 = last(2);
        z(i1:j1,i2:j2) = x;
    elseif rank == 3
        i1 = first(1); j1 = last(1);
        i2 = first(2); j2 = last(2);
        i3 = first(3); j3 = last(3);
        z(i1:j1,i2:j2,i3:j3) = x;
    elseif rank == 4
        i1 = first(1); j1 = last(1);
        i2 = first(2); j2 = last(2);
        i3 = first(3); j3 = last(3);
        i4 = first(4); j4 = last(4);
        z(i1:j1,i2:j2,i3:j3,i4:j4) = x;
    elseif rank == 5
        i1 = first(1); j1 = last(1);
        i2 = first(2); j2 = last(2);
        i3 = first(3); j3 = last(3);
        i4 = first(4); j4 = last(4);
        i5 = first(5); j5 = last(5);
        z(i1:j1,i2:j2,i3:j3,i4:j4,i5:j5) = x;
    elseif rank == 6
        i1 = first(1); j1 = last(1);
        i2 = first(2); j2 = last(2);
        i3 = first(3); j3 = last(3);
        i4 = first(4); j4 = last(4);
        i5 = first(5); j5 = last(5);
        i6 = first(6); j6 = last(6);
        z(i1:j1,i2:j2,i3:j3,i4:j4,i5:j5,i6:j6) = x;
    else
        printf('ERROR - too many dimensions\n');
    end
end

